==> _private_core_network-1.1.5.tar.gz: lib/network_resources/common/app_api.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/provider/client_web.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';  

import 'models/platform_user_detail.dart';
import 'models/platform_user_list.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String trackOnClick() => "v2/common/trackOnClick";
  static String getPlatformsUsersFromAdmin() => "v2/common/getPlatformsUsersFromAdmin";
  static String getPlatformsUserDetailsFromAdmin() => "v2/common/getPlatformsUserDetailsFromAdmin";
}

abstract class MyAppApi {
  Future<NetworkResponse> trackOnClick(params);
  Future<NetworkResponse> getPlatformsUsersFromAdmin(params);
  Future<NetworkResponse> getPlatformsUserDetailsFromAdmin(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getPlatformsUsersFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true,
              token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getPlatformsUsersFromAdmin(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformUserList.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPlatformsUserDetailsFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true,
              token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getPlatformsUserDetailsFromAdmin(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformUserDetail.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
  @override
  Future<NetworkResponse> trackOnClick(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true,
              token: await appPrefs.getNormalToken())
          .post(_MyAppEndpoint.trackOnClick(), data: params);
      return NetworkResponse.fromResponse(
        response,
        value: response.statusCode == 200,
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}

==> _private_core_network-1.2.25.tar.gz: lib/network_resources/common/app_api.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';

import 'models/platform_user_detail.dart';
import 'models/platform_user_list.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String trackOnClick() => "v2/common/trackOnClick";
  static String getPlatformsUsersFromAdmin() =>
      "v2/common/getPlatformsUsersFromAdmin";
  static String getPlatformsUserDetailsFromAdmin() =>
      "v2/common/getPlatformsUserDetailsFromAdmin";
}

abstract class MyAppApi {
  Future<NetworkResponse> trackOnClick(params);
  Future<NetworkResponse> getPlatformsUsersFromAdmin(params);
  Future<NetworkResponse> getPlatformsUserDetailsFromAdmin(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getPlatformsUsersFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getPlatformsUsersFromAdmin(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformUserList.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPlatformsUserDetailsFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getPlatformsUserDetailsFromAdmin(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformUserDetail.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> trackOnClick(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(_MyAppEndpoint.trackOnClick(), data: params);
      return NetworkResponse.fromResponse(
        response,
        value: response.statusCode == 200,
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}
